@@ -1,11 +1,11 @@
 # -*- coding:utf-8 -*-
 
 import redis
-import time
 import datetime
 import urlparse
 import socket
 import json
+import time
 from contextlib import contextmanager
 
 try:
@@ -17,17 +17,23 @@ from bs4 import BeautifulSoup
 
 from .utils import parse_yandex, parse_google
 from .mixin import openYandexMixin
+from .decorators import fail_counter
 
 MAX_OPEN_LINKS = 50
+TIMEOUT = settings.TIMEOUT if hasattr(settings, 'TIMEOUT') else 120
 
 
-class TimeoutError(Exception):
-    pass
+def sendData(string,server, port):
+    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    s.settimeout(TIMEOUT)
+    print server + ':' + str(port)
+    s.connect((server, port))
+    s.send(string)
 
 
 def getData(string, server, port):
     s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-    s.settimeout(120)
+    s.settimeout(TIMEOUT)
     print server + ':' + str(port)
     s.connect((server, port))
     s.send(string)
@@ -38,7 +44,7 @@ def getData(string, server, port):
     while True:
         data += s.recv(1024)
         if (datetime.datetime.now() - datetime.timedelta(seconds=60)) > now:
-            raise TimeoutError
+            raise socket.timeout('Fail when get soup')
 
         if '###end###' in data:
             text = data.replace('###end###', '')
@@ -48,7 +54,7 @@ def getData(string, server, port):
 
 def getServer():
     s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-    s.settimeout(120)
+    s.settimeout(TIMEOUT)
     s.connect(settings.ANTI_BALANCER)
     string = "###GET_SERVER###"
     s.send(string)
@@ -58,8 +64,8 @@ def getServer():
 
     while True:
         data += s.recv(1024)
-        if (datetime.datetime.now() - datetime.timedelta(seconds=60)) > now:
-            raise TimeoutError
+        if (datetime.datetime.now() - datetime.timedelta(seconds=TIMEOUT)) > now:
+            raise socket.timeout('All servers is binding')
 
         if '###end###' in data:
             text = data.replace('###end###', '')
@@ -75,31 +81,19 @@ class openYandex(openYandexMixin):
 
     @contextmanager
     def ip_port(self):
-        # Получаем  ip+port из балансера
-        for counter in xrange(5):
-            try:
-                self.redis_key, self.server, self.port = getServer()
-                break
-            except (TimeoutError, socket.timeout) as exc:
-                self.soup = '<p>%s</p>' % exc
-                time.sleep(3)
+        self.redis_key, self.server, self.port = getServer()
 
-        # Получаем состояние воркера
         try:
             self.state = json.loads(self.rds.get(self.redis_key))
         except:
             self.state = {'counter': 0, 'state': True}
 
-        # Выполняем контекст
-        for counter in xrange(5):
-            try:
-                yield
-                break
-            except Exception as exc:
-                self.soup = '<p>%s</p>' % exc
-                time.sleep(3)
-            finally:
-                self.update_state()
+        try:
+            yield
+        except:
+            raise
+        finally:
+            self.update_state()
 
     def update_state(self):
         """ Обновление состояния браузера и рестарт в случае надобности """
@@ -107,11 +101,13 @@ class openYandex(openYandexMixin):
             self.state['counter'] += 1
             if self.state['counter'] >= MAX_OPEN_LINKS:
                 string = '###restart###'
-                getData(string, self.server, self.port)
+                sendData(string, self.server, self.port)
+                time.sleep(7)
                 self.state['counter'] = 0
             self.state['state'] = False
             self.rds.set(self.redis_key, json.dumps(self.state))
 
+    @fail_counter
     def get_soup(self, url, save=True, counter=0, normalize=False):
         """ Получение супа в ответе сервера """
         self.url = url
@@ -136,10 +132,11 @@ class openYandex(openYandexMixin):
 
     def formatData(self, soup):
         """ Формирование данных """
+        data = None
         if 'yandex.ru' == self.hostname:
             data = parse_yandex(soup, self.query)
             if data is False:
-                self.get_soup(self.url, self.save, self.counter, self.normalize)
+                data = self.get_soup(self.url, self.save, self.counter, self.normalize)
         if 'www.google.ru' == self.hostname:
             data = parse_google(soup, self.query)
         return data
