@@ -5,6 +5,8 @@ import datetime
 import urllib
 import json
 
+from .anti_config import db, Key, Pos, Host, Url
+
 from .utils import get_normal_url, get_normal_quote, parse_google_url
 
 
@@ -15,7 +17,7 @@ GOOGLE_URL = 'https://www.google.ru/search?num=100&q=%s'
 
 
 class openYandexMixin():
-    def get_yandex_cache_pos(self, phrase, lr=213):
+    def get_yandex_cache_pos(self, phrase, lr=213, storage=True):
         """ data = obj.get_yandex_cache_pos(phrase, lr?). Получим позиции по ключевой фразе(первые 100)"""
         phrase_quote = get_normal_quote(phrase)
         res = []
@@ -24,17 +26,30 @@ class openYandexMixin():
             data = self.rds.get('page:' + url)
             if data:
                 res += json.loads(data)
-            else:
+            elif storage:
                 res += self.get_soup(url, normalize=True)
         return res
 
-    def get_google_cache_pos(self, phrase):
+    def get_yandex_date_pos(self, phrase, date, lr=213):
+        res = db.session.query(Pos.pos,
+                               Key.key,
+                               Host.host,
+                               Url.url,
+                               Pos.search,
+                               Pos.lr)\
+                        .join(Key).join(Host).join(Url)\
+                        .filter(Key.key == phrase, Pos.date == date, Pos.lr == lr).all()
+        return res
+
+    def get_google_cache_pos(self, phrase, storage=True):
         phrase_quote = get_normal_quote(phrase)
         url = GOOGLE_URL % phrase_quote
         data = self.rds.get('page:' + url)
+        res = []
         if data:
-            return json.loads(data)
-        res = self.get_soup(url, normalize=True)
+            res = json.loads(data)
+        elif storage:
+            res = self.get_soup(url, normalize=True)
         return res
 
     def clear_yandex_cache_pos(self, phrase, lr=213):
@@ -66,20 +81,20 @@ class openYandexMixin():
 
             for block in blocks:
                 for item in block:
-                    tlink = item.find('a', class_ = 'serp-url__link')
+                    tlink = item.find('a', class_='serp-url__link')
                     if tlink:
                         host = get_normal_url(tlink['href'])
                         if 'yandex.ru' not in host and 'infected?' not in host:
-                            url = item.find('a', class_ = 'serp-item__title-link').get('href')
-                            title = item.find('a', class_ = 'serp-item__title-link').text
-                            desc = item.find('div', class_ = 'serp-item__text')
+                            url = item.find('a', class_='serp-item__title-link').get('href')
+                            title = item.find('a', class_='serp-item__title-link').text
+                            desc = item.find('div', class_='serp-item__text')
                             desc = desc.text if desc else None
                             if url not in [i['url'] for i in pages]:
                                 pages.append({'url': url, 'title': title, 'desc': desc})
 
-        link = soup(text=u'Следующая')
+        link = soup.find('a', class_='pager__item_kind_next')
         if link:
-            link = 'http://yandex.ru' + link[0].parent.parent['href']
+            link = 'http://yandex.ru' + link['href']
             self.pages_of_site_in_index_yandex(site, pages, link)
         return pages
 
