@@ -5,6 +5,7 @@ import re
 import httplib
 import requests
 import whois
+import urlparse
 
 from bs4 import BeautifulSoup
 
@@ -74,10 +75,9 @@ class SeoParser():
             return 0
 
     def GetYaca(self):
-        yurl = 'http://bar-navig.yandex.ru/u?ver=2&show=32&url=%s' % self.site
-        f = requests.get(yurl, timeout=120)
-        st = f.text
-        m = re.search(r'<textinfo>(?P<author>[\W\w]+)</textinfo>', st)
+        yurl = 'http://bar-navig.yandex.ru/u?ver=2&show=32&url=http://%s' % self.site
+        resp = requests.get(yurl, timeout=120)
+        m = re.search(r'<textinfo>(?P<author>[\W\w]+)</textinfo>', resp.text)
         try:
             self.yaca = m.group(1)
         except:
@@ -129,8 +129,9 @@ class SeoParser():
         try:
             reqst = requests.get(url, timeout=120, verify=False)
             if len(reqst.history) > 0:
-                if remove_last_slash(reqst.url) == www_url and 302 not in [item.status_code for item in reqst.history]:
-                    return 'www.'
+                if urlparse.urlparse(reqst.url).netloc == urlparse.urlparse(www_url).netloc:
+                    if 302 not in [item.status_code for item in reqst.history]:
+                        return 'www.'
 
         except requests.ConnectionError:
             pass
@@ -141,8 +142,10 @@ class SeoParser():
         try:
             reqst = requests.get(www_url, timeout=120, verify=False)
             if len(reqst.history) > 0:
-                if remove_last_slash(reqst.url) == url and 302 not in [item.status_code for item in reqst.history]:
-                    return True
+
+                if urlparse.urlparse(reqst.url).netloc == urlparse.urlparse(url).netloc:
+                    if 302 not in [item.status_code for item in reqst.history]:
+                        return True
         except:
             pass
 
