@@ -124,12 +124,13 @@ def parse_google_url(url):
         return query.get('q')[0]
     return ''
 
+
 def parse_yandex(soup, query):
     data = []
     blocks = soup.find_all(class_='serp-block')
     if blocks:
         blocks = [item for item in blocks
-                    if len(item.attrs.get('class')) < 3 or 'serp-block_type_site' in item.attrs.get('class')]
+                  if len(item.attrs.get('class')) < 3 or 'serp-block_type_site' in item.attrs.get('class')]
 
         params = urlparse.parse_qs(query)
         key = params['text'][0]
@@ -141,7 +142,7 @@ def parse_yandex(soup, query):
         for block in blocks:
             for item in block:
                 tlink = item.find('a', class_='serp-url__link')
-                if tlink:
+                if tlink and 'serp-item_plain_yes' in item['class']:
                     pos += 1
                     host = get_normal_url(tlink['href'])
                     if 'yandex.ru' not in host and 'infected?' not in host:
@@ -150,15 +151,17 @@ def parse_yandex(soup, query):
     if len(blocks) == 0:
         if unicode(soup).find(u'По вашему запросу ничего не нашлось') == -1:
             return False
+
     return data
 
+
 def parse_google(soup, query):
     data = []
     params = urlparse.parse_qs(query)
     key = params['q'][0]
     pos = int(params['start'][0]) if 'start' in params else 0
 
-    for item in soup.findAll('li', {'class': 'g'}):
+    for item in soup.find_all(class_='g'):
         pos += 1
         if item.find('cite'):
             res = re.search(r'(https://)?(www.)?([^/\ ]+)', item.find('cite').text)
